%define libs %mklibname %{name}
%define devel %mklibname %{name} -d

# to workaround a limitation where %%{name} can't be used before it's defined
%global name unimrcp-deps

# filter out private libraries from provides (mga#18831#c8)
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}%{_libdir}/%{name}/lib.*\\.so

# filter out reqs for bundled libs also available system-wide
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}lib(apr-1|sofia-sip-ua)\\.so\\.[0-9]\+

# filter out devel pkg reqs for bundled libs
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}devel\\(lib(apr(|util)-1|sofia-sip-ua).*\)

%global optflags %optflags -fpermissive
%define _uver %(tr . -<<<%{version})

Name:           %{name}
Version:        1.6.0
Release:        %mkrel 3
Summary:        Media Resource Control Protocol Stack
License:        Apache
Group:          System/Libraries
Url:            https://unimrcp.org/
Source:         https://unimrcp.org/project/component-view/unimrcp-deps-%{_uver}-tar-gz/%{name}-%{version}.tar.gz
Patch0:         unimrcp-deps-1.6.0-fix-configure-for-gcc15.patch

BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool

%package -n     %{libs}
Summary:        UniMRCP depends Stack shared libraries
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}
Provides:       bundled(apr) = 1.5.2
Provides:       bundled(apr-util) = 1.5.4
Provides:       bundled(sofia-sip) = 1.12.11

%package -n     %{devel}
Summary:        UniMRCP depends Stack development
Group:          Development/C
Provides:       lib%{name}-devel = %{version}-%{release}
Requires:       lib%{name} = %{version}-%{release}

%description
UniMRCP depends on a number of third party tools and libraries, which are
required and must be installed first. Alternatively, the original packages
of APR, APR-Util and Sofia-SIP libraries and patches for them
can be downloaded from https://www.unimrcp.org/dependencies/

%description -n %{libs}
UniMRCP depends on a number of third party tools and libraries, which are
required and must be installed first. Alternatively, the original packages
of APR, APR-Util and Sofia-SIP libraries and patches for them
can be downloaded from https://www.unimrcp.org/dependencies/

%description -n %{devel}
UniMRCP depends on a number of third party tools and libraries, which are
required and must be installed first. Alternatively, the original packages
of APR, APR-Util and Sofia-SIP libraries and patches for them
can be downloaded from https://www.unimrcp.org/dependencies/

%prep
%setup -q
%autopatch -p1

%build
cd libs/apr
autoreconf -fi
%configure \
        --enable-threads \
        --disable-static \
        --includedir=%{_includedir}/%{name} \
        --libdir=%{_libdir}/%{name}/lib \
        --bindir=%{_libdir}/%{name}/bin \
        --datadir=%{_datadir}/%{name} \
        --prefix=%{_prefix}
%make_build

cd ../apr-util
autoreconf -fi
%configure \
        --with-apr=../apr \
        --includedir=%{_includedir}/%{name} \
        --libdir=%{_libdir}/%{name}/lib \
        --bindir=%{_libdir}/%{name}/bin \
        --datadir=%{_datadir}/%{name} \
        --prefix=%{_prefix}
%make_build

cd ../sofia-sip
autoreconf -fi
%configure \
        --disable-static \
        --disable-silent-rules \
        --with-glib=no \
        --includedir=%{_includedir}/%{name} \
        --libdir=%{_libdir}/%{name}/lib \
        --bindir=%{_libdir}/%{name}/bin \
        --datadir=%{_datadir}/%{name} \
        --prefix=%{_prefix}
%make_build

%install
%make_install -C libs/apr

%make_install -C libs/apr-util

%make_install -C libs/sofia-sip

%files -n %{libs}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/lib
%{_mandir}/man1/addrinfo.1.*
%{_mandir}/man1/localinfo.1.*
%{_mandir}/man1/sip-date.1.*
%{_mandir}/man1/sip-dig.1.*
%{_mandir}/man1/sip-options.1.*
%{_mandir}/man1/stunc.1.*
%exclude %{_libdir}/%{name}/lib/lib*.so
%exclude %{_libdir}/%{name}/lib/pkgconfig

%files -n %{devel}
%{_libdir}/%{name}/lib/lib*.so
%{_includedir}/%{name}/
%{_datadir}/%{name}/build-1
%{_libdir}/%{name}/bin
%{_datadir}/%{name}/sofia-sip
%{_libdir}/%{name}/lib/pkgconfig/


%changelog
* Wed Jun 25 2025 aurr <aurr> 1.6.0-3.mga10
+ Revision: 2194796
- patch for gcc15

* Thu Sep 22 2022 wally <wally> 1.6.0-2.mga9
+ Revision: 1891537
- add bundled() provides
- filter out bundled lib provides and requires
- fix provides excludes
- install archfull stuff into %%{_libdir}/unimrcp-deps/ to avoid rpath issues
- install devel headers into %%{_includedir}/unimrcp-deps/

* Thu Sep 22 2022 papoteur <papoteur> 1.6.0-1.mga9
+ Revision: 1891415
- new 1.6.0
+ neoclust <neoclust>
- Rebuild against openssl
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ wally <wally>
- rebuild for openssl 3.0.0

* Fri Feb 14 2020 umeabot <umeabot> 1.5.0-3.mga8
+ Revision: 1517712
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 1.5.0-2.mga7
+ Revision: 1301524
- Mageia 7 Mass Rebuild

* Wed May 30 2018 daviddavid <daviddavid> 1.5.0-1.mga7
+ Revision: 1233130
- new version: 1.5.0
- enable sqlite3 support
- disable static libraries and drop '.la' files

* Sat Sep 23 2017 daviddavid <daviddavid> 1.1.2-10.mga7
+ Revision: 1158123
- rebuild for new openssl 1.1.0

* Sun Nov 27 2016 daviddavid <daviddavid> 1.1.2-9.mga6
+ Revision: 1070433
- filter out private libraries from provides (mga#18831#c8)
- move some devel files into devel subpackage
- fix ownership of data dir

* Thu Mar 03 2016 umeabot <umeabot> 1.1.2-8.mga6
+ Revision: 984691
- Rebuild for openssl

* Fri Feb 12 2016 umeabot <umeabot> 1.1.2-7.mga6
+ Revision: 959089
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.1.2-6.mga5
+ Revision: 742078
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.1.2-5.mga5
+ Revision: 725272
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.1.2-4.mga5
+ Revision: 690047
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.1.2-3.mga4
+ Revision: 519921
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.1.2-2.mga3
+ Revision: 385066
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 dlucio <dlucio> 1.1.2-1.mga3
+ Revision: 339832
- 1.1.2
- filelist fixed

* Mon Apr 02 2012 pterjan <pterjan> 1.1.0-2.mga2
+ Revision: 227807
- Rebuild after libexpat.la removal

* Sun Mar 25 2012 dlucio <dlucio> 1.1.0-1.mga2
+ Revision: 226306
- imported package unimrcp-deps


* Thu Feb 16 2012 Denis Silakov <dsilakov@mandriva.org> 1.1.0-1mdv2012.0
+ Revision: 775094
- Reformat description to shorten lines

  + zamir <zamir@mandriva.org>
    - search build error
    - clear provides

* Sun Aug 21 2011 zamir <zamir@mandriva.org> 1.1.0-0
+ Revision: 695980
- may be need expat source?.. try
- try again
- try again
- try fix script creating dir
- build new pkg version

* Mon Feb 28 2011 Funda Wang <fwang@mandriva.org> 1.0.2-3
+ Revision: 640872
- rebuild

* Sat Feb 12 2011 zamir <zamir@mandriva.org> 1.0.2-2
+ Revision: 637390
- change depend
- fixed requires

* Fri Feb 11 2011 zamir <zamir@mandriva.org> 1.0.2-1
+ Revision: 637315
- changed provide information
- changed provide information

* Fri Feb 11 2011 zamir <zamir@mandriva.org> 1.0.2-0
+ Revision: 637269
- first build
- create unimrcp-deps

